<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>Dialog</name>
    <message>
        <source>Perturbation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Julia-seed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Morphing type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Startuptime:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stoptime:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Files to render:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Basename:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pixel width (cm):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pixel height (cm):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Framerate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Antialiasing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always recalculate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Center:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Angle:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotations per second:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Letters per second:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Iterations:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Formula:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X center:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y center:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X Radius:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y Radius:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Coordinates:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>continuous rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fast rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zooming speed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bailout:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Threads:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Julia mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dynamic resolution:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Algorithm number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load Palette Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Palette Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frames per second:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Formula</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initialization:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Error</name>
    <message>
        <source>renderanim: Width parameter must be positive integer in the range 0..4096</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>renderanim: Height parameter must be positive integer in the range 0..4096</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>renderanim: Invalid real width and height dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>renderanim: invalid framerate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>renderanim: antialiasing not supported in 256 color mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>animateview: Invalid viewpoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid viewpoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown palette type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initialization of color cycling failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Try to enable palette emulation filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Algorithm:%i seed:%i size:%i</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>line available only in animation replay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Morphing non existing line!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>linekey not available in this context!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>clear_line available only in animation replay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>clear_lines available only in animation replay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Catalog file not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replay is already active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File open failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Out of memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing parameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unexpected end of file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Token is too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown formula type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>morph available only in animation replay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>morphview: Invalid viewpoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>move available only in animation replay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>morphjulia available only in animation replay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>morphangle available only in animation replay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sleep available only in animation replay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal program error #12 %i
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>wait available only in animation replay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No catalog file loaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message not found in catalog file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>load available only in animation replay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include level overflow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Too many parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error: %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot create palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot create image
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot create checking buffer!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot create context
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open animation file
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Calculation interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Calculation finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tutorial files not found. Reinstall XaoS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not open examples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not open image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not create palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XaoS is out of memory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not create image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not allocate tables</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Root menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animation root menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replay only commands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line drawing functions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Morph line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Morph last line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set line key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear all lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animation functions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Morph view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Morph julia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Morph angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Un-zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop zooming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smooth morphing parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timing functions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Usleep</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wait for text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wait for complete image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Formula</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximal zooming step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zooming speedup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Letters per second</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Interrupt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ministatus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cartesian Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fractal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Calculation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tutorials</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop replay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display fractal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal text position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical text position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save as</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PNG</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Render</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Render Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load random example</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Formulae</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More formulae</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User formula</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User initialization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Incoloring mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outcoloring mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plane</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mandelbrot mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Julia mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fast julia mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set plane</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inside coloring mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outside coloring mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inside truecolor coloring mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outside truecolor coloring mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Julia seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Palette Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Palette Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load Palette Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Palette Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color cycling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reversed color cycling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color cycling speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift one forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift one backward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Solid guessing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable solid guessing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guess 2x2 rectangles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guess 3x3 rectangles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guess 4x4 rectangles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guess 5x5 rectangles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guess 6x6 rectangles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guess 7x7 rectangles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guess 8x8 rectangles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guess unlimited rectangles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dynamic resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Periodicity checking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Threads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Iterations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bailout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Perturbation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zooming speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fixed step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Solid guessing range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continuous rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate by mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotation speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fast rotation mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recalculate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable dynamic resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use only during animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use also for new images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dynamic resolution mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autopilot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An introduction to fractals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XaoS features overview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Math behind fractals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other fractal types in XaoS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>What&apos;s new?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Whole story</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mandelbrot set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Julia set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Higher power Mandelbrots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Newton&apos;s method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Barnsley&apos;s formula</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phoenix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Octo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Magnet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All features</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outcoloring modes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Incoloring modes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>True-color coloring modes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Planes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animations and position files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random palettes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other noteworthy features</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The definition and fractal dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Escape time fractals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Triceratops and Catseye fractals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mandelbar, Lambda, Manowar and Spider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sierpinski Gasket, S.Carpet, Koch Snowflake</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>What&apos;s new in 3.0?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>What&apos;s new in 4.0?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message Font...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Info on current fractal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send Feedback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Forum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy position URL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Message</name>
    <message>
        <source>Boundary trace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Solid guessing 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Solid guessing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Out of memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unbalanced parentheses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown function: %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid number: %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown variable: %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid operator: %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal error occurred in formula: %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Function has incorrect parameter count: %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty formula</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XaoS must restart to change the thread count.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to quit now?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File %s opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File %s saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replay disabled at line %i</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initializing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading catalogs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Processing command line options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabling animation replay
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Entering calculation loop!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendering frame %i...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Linking frame %i to %i...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Calculation finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preparing first image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File %s loaded.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not open file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording to file %s enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%s %.2f times (%.1fE) %2.2f frames/sec %c %i %i %i %u            </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unzoomed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zoomed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>framerate:%f
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fractal name:%s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fractal type:%s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mandelbrot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Julia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Formula:%s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View:[%1.12f,%1.12f]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>size:[%1.12f,%1.12f]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotation:%4.2f   Screen size:%i:%i</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Iterations:%-4u Palette size:%i</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bailout:%4.2f</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autopilot:%-4s  Plane:%s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>incoloring:%s    outcoloring:%s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zoomspeed:%f</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parameter:none</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parameter:[%f,%f]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thank you for using XaoS
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XaoS must restart to change the language.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabling: %s. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabling: %s. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Letters per second %i  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotation speed:%2.2f degrees per second </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Iterations: %i   </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cycling speed: %i   </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>speed:%2.2f </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please wait while calculating %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Welcome to XaoS version %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clipboard set to %s.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse:[%1.12f,%1.12f]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
